==> pwsafe-3.05-src.zip: pwsafe-3.05-src/corelib/corelib.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_EXPORTHEADER               3002
#define IDSC_EXPHDRGROUPTITLE           3003
#define IDSC_EXPHDRUSERNAME             3004
#define IDSC_EXPHDRPASSWORD             3005
#define IDSC_EXPHDRURL                  3006
#define IDSC_EXPHDRAUTOTYPE             3007
#define IDSC_EXPHDRCTIME                3008
#define IDSC_EXPHDRPMTIME               3009
#define IDSC_EXPHDRATIME                3010
#define IDSC_EXPHDRLTIME                3011
#define IDSC_EXPHDRRMTIME               3012
#define IDSC_EXPHDRPWHISTORY            3013
#define IDCS_EXPHDRNOTES                3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPHDRLINEIGNORED          3016
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTGETLOCKER              3020
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_LOCKUNKNOWNERROR           3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_XMLPARSEERROR              3043
#define IDSC_XMLBADCREATESCHEMA         3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOXMLREADER                3047
#define IDSC_XMLHEADER                  3048
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_SAXERRORPWH                3051
#define IDSC_SAXGENERROR                3052
                                        
#define IDSC_FILEEXCEPTION00            3100
#define IDSC_FILEEXCEPTION01            3101
#define IDSC_FILEEXCEPTION02            3102
#define IDSC_FILEEXCEPTION03            3103
#define IDSC_FILEEXCEPTION04            3104
#define IDSC_FILEEXCEPTION05            3105
#define IDSC_FILEEXCEPTION06            3106
#define IDSC_FILEEXCEPTION07            3107
#define IDSC_FILEEXCEPTION08            3108
#define IDSC_FILEEXCEPTION09            3109
#define IDSC_FILEEXCEPTION10            3110
#define IDSC_FILEEXCEPTION11            3111
#define IDSC_FILEEXCEPTION12            3112
#define IDSC_FILEEXCEPTION13            3113
#define IDSC_FILEEXCEPTION14            3114
                                        
#define IDSC_CONFIG_NONE                 3230
#define IDSC_CONFIG_REGISTRY             3231
#define IDSC_CONFIG_FILE_RO              3232
#define IDSC_CONFIG_FILE_RW              3233

==> pwsafe-3.05.02-src.zip: pwsafe-3.05.02-src/corelib/corelib.h <==
//{{NO_DEPENDENCIES}}

// Non-editable by VS2005

#define IDSC_PASSWORDTOOSHORT           3000
#define IDSC_PASSWORDPOOR               3001
#define IDSC_EXPORTHEADER               3002
#define IDSC_EXPHDRGROUPTITLE           3003
#define IDSC_EXPHDRUSERNAME             3004
#define IDSC_EXPHDRPASSWORD             3005
#define IDSC_EXPHDRURL                  3006
#define IDSC_EXPHDRAUTOTYPE             3007
#define IDSC_EXPHDRCTIME                3008
#define IDSC_EXPHDRPMTIME               3009
#define IDSC_EXPHDRATIME                3010
#define IDSC_EXPHDRLTIME                3011
#define IDSC_EXPHDRRMTIME               3012
#define IDSC_EXPHDRPWHISTORY            3013
#define IDCS_EXPHDRNOTES                3014
#define IDSC_IMPMISSINGQUOTE            3015
#define IDSC_IMPHDRLINEIGNORED          3016
#define IDSC_IMPINVALIDINPUT            3017
#define IDSC_IMPINVALIDPWH              3018
#define IDSC_NOLOCKACCESS               3019
#define IDSC_CANTGETLOCKER              3020
#define IDSC_CANTREADLOCKER             3021
#define IDSC_INTERNALLOCKERROR          3022
#define IDSC_SYSTEMLOCKERROR            3023
#define IDSC_LOCKFILEPATHNF             3024
#define IDSC_LOCKUNKNOWNERROR           3025
#define IDSC_NUMPROCESSED               3026
#define IDSC_AUTOTYPE                   3027
#define IDSC_NOCONFIGLOCK               3028
#define IDSC_CANTCREATEXMLCFG           3029
#define IDSC_CANTUPDATEXMLCFG           3030
#define IDSC_CANTDETERMINECFG           3031
#define IDSC_CANTUSECONFIGFILE          3032
#define IDSC_PWHERROR                   3033
#define IDSC_INVALIDHEADER              3034
#define IDSC_INVALIDPWHSTATUS           3035
#define IDSC_INVALIDNUMOLDPW            3036
#define IDSC_INVALIDDATETIME            3037
#define IDSC_INVALIDPWLENGTH            3038
#define IDSC_FIELDTOOSHORT              3039
#define IDSC_FIELDTOOLONG               3040
#define IDSC_INVALIDSEPARATER           3041
#define IDSC_CANTXMLVALIDATE            3042
#define IDSC_XMLPARSEERROR              3043
#define IDSC_XMLBADCREATESCHEMA         3044
#define IDSC_XMLVALIDATION              3045
#define IDSC_XMLIMPORT                  3046
#define IDSC_NOXMLREADER                3047
#define IDSC_XMLHEADER                  3048
#define IDSC_XMLFILEERROR               3049
#define IDSC_XMLLOADFAILURE             3050
#define IDSC_XMLSAVEFAILURE             3051
#define IDSC_SAXERRORPWH                3052
#define IDSC_SAXGENERROR                3053
                                        
#define IDSC_FILEEXCEPTION00            3100
#define IDSC_FILEEXCEPTION01            3101
#define IDSC_FILEEXCEPTION02            3102
#define IDSC_FILEEXCEPTION03            3103
#define IDSC_FILEEXCEPTION04            3104
#define IDSC_FILEEXCEPTION05            3105
#define IDSC_FILEEXCEPTION06            3106
#define IDSC_FILEEXCEPTION07            3107
#define IDSC_FILEEXCEPTION08            3108
#define IDSC_FILEEXCEPTION09            3109
#define IDSC_FILEEXCEPTION10            3110
#define IDSC_FILEEXCEPTION11            3111
#define IDSC_FILEEXCEPTION12            3112
#define IDSC_FILEEXCEPTION13            3113
#define IDSC_FILEEXCEPTION14            3114
                                        
#define IDSC_CONFIG_NONE                 3230
#define IDSC_CONFIG_REGISTRY             3231
#define IDSC_CONFIG_FILE_RO              3232
#define IDSC_CONFIG_FILE_RW              3233
